# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class FailureType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    QUANTITY_NOT_SUFFICIENT_FAILURE = "quantity_not_sufficient_failure"
    COLLECTION_PROCESS_FAILURE = "collection_process_failure"
    DROP_OFF_FAILURE = "drop_off_failure"
    INTERNAL_LAB_FAILURE = "internal_lab_failure"
    ORDER_ENTRY_FAILURE = "order_entry_failure"
    NON_FAILURE = "non_failure"
    UNKNOWN_FAILURE = "unknown_failure"
    PATIENT_CONDITION_FAILURE = "patient_condition_failure"
    MISSING_RESULT_CALC_FAILURE = "missing_result_calc_failure"
    MISSING_DEMO_AOE_CALC_FAILURE = "missing_demo_aoe_calc_failure"
    INSUFFICIENT_VOLUME = "insufficient_volume"
    _UNKNOWN = "__FAILURETYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "FailureType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        quantity_not_sufficient_failure: typing.Callable[[], T_Result],
        collection_process_failure: typing.Callable[[], T_Result],
        drop_off_failure: typing.Callable[[], T_Result],
        internal_lab_failure: typing.Callable[[], T_Result],
        order_entry_failure: typing.Callable[[], T_Result],
        non_failure: typing.Callable[[], T_Result],
        unknown_failure: typing.Callable[[], T_Result],
        patient_condition_failure: typing.Callable[[], T_Result],
        missing_result_calc_failure: typing.Callable[[], T_Result],
        missing_demo_aoe_calc_failure: typing.Callable[[], T_Result],
        insufficient_volume: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is FailureType.QUANTITY_NOT_SUFFICIENT_FAILURE:
            return quantity_not_sufficient_failure()
        if self is FailureType.COLLECTION_PROCESS_FAILURE:
            return collection_process_failure()
        if self is FailureType.DROP_OFF_FAILURE:
            return drop_off_failure()
        if self is FailureType.INTERNAL_LAB_FAILURE:
            return internal_lab_failure()
        if self is FailureType.ORDER_ENTRY_FAILURE:
            return order_entry_failure()
        if self is FailureType.NON_FAILURE:
            return non_failure()
        if self is FailureType.UNKNOWN_FAILURE:
            return unknown_failure()
        if self is FailureType.PATIENT_CONDITION_FAILURE:
            return patient_condition_failure()
        if self is FailureType.MISSING_RESULT_CALC_FAILURE:
            return missing_result_calc_failure()
        if self is FailureType.MISSING_DEMO_AOE_CALC_FAILURE:
            return missing_demo_aoe_calc_failure()
        if self is FailureType.INSUFFICIENT_VOLUME:
            return insufficient_volume()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class MenstrualFlowEntryFlow(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    UNSPECIFIED = "unspecified"
    NONE = "none"
    LIGHT = "light"
    MEDIUM = "medium"
    HEAVY = "heavy"
    _UNKNOWN = "__MENSTRUALFLOWENTRYFLOW_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "MenstrualFlowEntryFlow":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        unspecified: typing.Callable[[], T_Result],
        none: typing.Callable[[], T_Result],
        light: typing.Callable[[], T_Result],
        medium: typing.Callable[[], T_Result],
        heavy: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is MenstrualFlowEntryFlow.UNSPECIFIED:
            return unspecified()
        if self is MenstrualFlowEntryFlow.NONE:
            return none()
        if self is MenstrualFlowEntryFlow.LIGHT:
            return light()
        if self is MenstrualFlowEntryFlow.MEDIUM:
            return medium()
        if self is MenstrualFlowEntryFlow.HEAVY:
            return heavy()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ProviderLinkResponseErrorType(str, enum.Enum):
    INVALID_TOKEN = "invalid_token"
    TOKEN_EXPIRED = "token_expired"
    TOKEN_NOT_VALIDATED = "token_not_validated"
    TOKEN_CONSUMED = "token_consumed"
    PROVIDER_CREDENTIAL_ERROR = "provider_credential_error"
    PROVIDER_PASSWORD_EXPIRED = "provider_password_expired"
    PROVIDER_API_ERROR = "provider_api_error"
    UNSUPPORTED_REGION = "unsupported_region"
    DUPLICATE_CONNECTION = "duplicate_connection"
    REQUIRED_SCOPES_NOT_GRANTED = "required_scopes_not_granted"
    INCORRECT_MFA_CODE = "incorrect_mfa_code"
    USER_CANCELLED = "user_cancelled"
    _UNKNOWN = "__PROVIDERLINKRESPONSEERRORTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ProviderLinkResponseErrorType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        invalid_token: typing.Callable[[], T_Result],
        token_expired: typing.Callable[[], T_Result],
        token_not_validated: typing.Callable[[], T_Result],
        token_consumed: typing.Callable[[], T_Result],
        provider_credential_error: typing.Callable[[], T_Result],
        provider_password_expired: typing.Callable[[], T_Result],
        provider_api_error: typing.Callable[[], T_Result],
        unsupported_region: typing.Callable[[], T_Result],
        duplicate_connection: typing.Callable[[], T_Result],
        required_scopes_not_granted: typing.Callable[[], T_Result],
        incorrect_mfa_code: typing.Callable[[], T_Result],
        user_cancelled: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ProviderLinkResponseErrorType.INVALID_TOKEN:
            return invalid_token()
        if self is ProviderLinkResponseErrorType.TOKEN_EXPIRED:
            return token_expired()
        if self is ProviderLinkResponseErrorType.TOKEN_NOT_VALIDATED:
            return token_not_validated()
        if self is ProviderLinkResponseErrorType.TOKEN_CONSUMED:
            return token_consumed()
        if self is ProviderLinkResponseErrorType.PROVIDER_CREDENTIAL_ERROR:
            return provider_credential_error()
        if self is ProviderLinkResponseErrorType.PROVIDER_PASSWORD_EXPIRED:
            return provider_password_expired()
        if self is ProviderLinkResponseErrorType.PROVIDER_API_ERROR:
            return provider_api_error()
        if self is ProviderLinkResponseErrorType.UNSUPPORTED_REGION:
            return unsupported_region()
        if self is ProviderLinkResponseErrorType.DUPLICATE_CONNECTION:
            return duplicate_connection()
        if self is ProviderLinkResponseErrorType.REQUIRED_SCOPES_NOT_GRANTED:
            return required_scopes_not_granted()
        if self is ProviderLinkResponseErrorType.INCORRECT_MFA_CODE:
            return incorrect_mfa_code()
        if self is ProviderLinkResponseErrorType.USER_CANCELLED:
            return user_cancelled()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LabTestsGetOrdersRequestOrderKey(str, enum.Enum):
    CREATED_AT = "created_at"
    PATIENT_NAME = "patient_name"
    LAST_STATUS = "last_status"
    _UNKNOWN = "__LABTESTSGETORDERSREQUESTORDERKEY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "LabTestsGetOrdersRequestOrderKey":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        created_at: typing.Callable[[], T_Result],
        patient_name: typing.Callable[[], T_Result],
        last_status: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is LabTestsGetOrdersRequestOrderKey.CREATED_AT:
            return created_at()
        if self is LabTestsGetOrdersRequestOrderKey.PATIENT_NAME:
            return patient_name()
        if self is LabTestsGetOrdersRequestOrderKey.LAST_STATUS:
            return last_status()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ConsentType(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    TERMS_OF_USE = "terms-of-use"
    TELEHEALTH_INFORMED_CONSENT = "telehealth-informed-consent"
    MOBILE_TERMS_AND_CONDITIONS = "mobile-terms-and-conditions"
    NOTICE_OF_PRIVACY_PRACTICES = "notice-of-privacy-practices"
    PRIVACY_POLICY = "privacy-policy"
    HIPAA_AUTHORIZATION = "hipaa-authorization"
    _UNKNOWN = "__CONSENTTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ConsentType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        terms_of_use: typing.Callable[[], T_Result],
        telehealth_informed_consent: typing.Callable[[], T_Result],
        mobile_terms_and_conditions: typing.Callable[[], T_Result],
        notice_of_privacy_practices: typing.Callable[[], T_Result],
        privacy_policy: typing.Callable[[], T_Result],
        hipaa_authorization: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ConsentType.TERMS_OF_USE:
            return terms_of_use()
        if self is ConsentType.TELEHEALTH_INFORMED_CONSENT:
            return telehealth_informed_consent()
        if self is ConsentType.MOBILE_TERMS_AND_CONDITIONS:
            return mobile_terms_and_conditions()
        if self is ConsentType.NOTICE_OF_PRIVACY_PRACTICES:
            return notice_of_privacy_practices()
        if self is ConsentType.PRIVACY_POLICY:
            return privacy_policy()
        if self is ConsentType.HIPAA_AUTHORIZATION:
            return hipaa_authorization()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .lab_tests_get_orders_request_order_direction import LabTestsGetOrdersRequestOrderDirection
from .lab_tests_get_orders_request_order_key import LabTestsGetOrdersRequestOrderKey
from .lab_tests_get_paginated_request_order_direction import LabTestsGetPaginatedRequestOrderDirection
from .lab_tests_get_paginated_request_order_key import LabTestsGetPaginatedRequestOrderKey
from .lab_tests_get_request_order_direction import LabTestsGetRequestOrderDirection
from .lab_tests_get_request_order_key import LabTestsGetRequestOrderKey

__all__ = [
    "LabTestsGetOrdersRequestOrderDirection",
    "LabTestsGetOrdersRequestOrderKey",
    "LabTestsGetPaginatedRequestOrderDirection",
    "LabTestsGetPaginatedRequestOrderKey",
    "LabTestsGetRequestOrderDirection",
    "LabTestsGetRequestOrderKey",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Ethnicity(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    HISPANIC = "hispanic"
    NON_HISPANIC = "non_hispanic"
    ASHKENAZI_JEWISH = "ashkenazi_jewish"
    OTHER = "other"
    _UNKNOWN = "__ETHNICITY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "Ethnicity":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        hispanic: typing.Callable[[], T_Result],
        non_hispanic: typing.Callable[[], T_Result],
        ashkenazi_jewish: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is Ethnicity.HISPANIC:
            return hispanic()
        if self is Ethnicity.NON_HISPANIC:
            return non_hispanic()
        if self is Ethnicity.ASHKENAZI_JEWISH:
            return ashkenazi_jewish()
        if self is Ethnicity.OTHER:
            return other()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class HistoricalPullRetriableErrorDetails(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    PROVIDER_RATE_LIMIT_EXCEEDED = "provider_rate_limit_exceeded"
    PROVIDER_UNAVAILABLE = "provider_unavailable"
    TRANSPORT_FAILURE = "transport_failure"
    RESOURCE_CONTENTION = "resource_contention"
    _UNKNOWN = "__HISTORICALPULLRETRIABLEERRORDETAILS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "HistoricalPullRetriableErrorDetails":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        provider_rate_limit_exceeded: typing.Callable[[], T_Result],
        provider_unavailable: typing.Callable[[], T_Result],
        transport_failure: typing.Callable[[], T_Result],
        resource_contention: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is HistoricalPullRetriableErrorDetails.PROVIDER_RATE_LIMIT_EXCEEDED:
            return provider_rate_limit_exceeded()
        if self is HistoricalPullRetriableErrorDetails.PROVIDER_UNAVAILABLE:
            return provider_unavailable()
        if self is HistoricalPullRetriableErrorDetails.TRANSPORT_FAILURE:
            return transport_failure()
        if self is HistoricalPullRetriableErrorDetails.RESOURCE_CONTENTION:
            return resource_contention()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .bad_request_error import BadRequestError
from .unprocessable_entity_error import UnprocessableEntityError

__all__ = ["BadRequestError", "UnprocessableEntityError"]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class GenderIdentity(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    MALE = "male"
    FEMALE = "female"
    FEMALE_TO_MALE_FTM_TRANSGENDER_MALE_TRANS_MAN = "female_to_male_ftm_transgender_male_trans_man"
    MALE_TO_FEMALE_MTF_TRANSGENDER_FEMALE_TRANS_WOMAN = "male_to_female_mtf_transgender_female_trans_woman"
    GENDERQUEER = "genderqueer"
    OTHER = "other"
    _UNKNOWN = "__GENDERIDENTITY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "GenderIdentity":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        male: typing.Callable[[], T_Result],
        female: typing.Callable[[], T_Result],
        female_to_male_ftm_transgender_male_trans_man: typing.Callable[[], T_Result],
        male_to_female_mtf_transgender_female_trans_woman: typing.Callable[[], T_Result],
        genderqueer: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is GenderIdentity.MALE:
            return male()
        if self is GenderIdentity.FEMALE:
            return female()
        if self is GenderIdentity.FEMALE_TO_MALE_FTM_TRANSGENDER_MALE_TRANS_MAN:
            return female_to_male_ftm_transgender_male_trans_man()
        if self is GenderIdentity.MALE_TO_FEMALE_MTF_TRANSGENDER_FEMALE_TRANS_WOMAN:
            return male_to_female_mtf_transgender_female_trans_woman()
        if self is GenderIdentity.GENDERQUEER:
            return genderqueer()
        if self is GenderIdentity.OTHER:
            return other()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class FallbackTimeZone(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    
        Fallback time zone of the user, in the form of a valid IANA tzdatabase identifier (e.g., `Europe/London` or `America/Los_Angeles`).
        Used when pulling data from sources that are completely time zone agnostic (e.g., all time is relative to UTC clock, without any time zone attributions on data points).
        
    """

    source_slug: str = pydantic.Field()
    """
    Slug for designated source
    """

    updated_at: dt.datetime

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class NoteTimeseriesExprField(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    SOURCE_PROVIDER = "source_provider"
    SOURCE_TYPE = "source_type"
    SOURCE_APP_ID = "source_app_id"
    SOURCE_WORKOUT_ID = "source_workout_id"
    SOURCE_SPORT = "source_sport"
    TIMEZONE_OFFSET = "timezone_offset"
    TYPE = "type"
    TAGS = "tags"
    CONTENT = "content"
    _UNKNOWN = "__NOTETIMESERIESEXPRFIELD_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "NoteTimeseriesExprField":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        source_provider: typing.Callable[[], T_Result],
        source_type: typing.Callable[[], T_Result],
        source_app_id: typing.Callable[[], T_Result],
        source_workout_id: typing.Callable[[], T_Result],
        source_sport: typing.Callable[[], T_Result],
        timezone_offset: typing.Callable[[], T_Result],
        type: typing.Callable[[], T_Result],
        tags: typing.Callable[[], T_Result],
        content: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is NoteTimeseriesExprField.SOURCE_PROVIDER:
            return source_provider()
        if self is NoteTimeseriesExprField.SOURCE_TYPE:
            return source_type()
        if self is NoteTimeseriesExprField.SOURCE_APP_ID:
            return source_app_id()
        if self is NoteTimeseriesExprField.SOURCE_WORKOUT_ID:
            return source_workout_id()
        if self is NoteTimeseriesExprField.SOURCE_SPORT:
            return source_sport()
        if self is NoteTimeseriesExprField.TIMEZONE_OFFSET:
            return timezone_offset()
        if self is NoteTimeseriesExprField.TYPE:
            return type()
        if self is NoteTimeseriesExprField.TAGS:
            return tags()
        if self is NoteTimeseriesExprField.CONTENT:
            return content()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .address import Address


class GuarantorDetails(UniversalBaseModel):
    first_name: str
    last_name: str
    address: Address
    phone_number: str
    household_income: typing.Optional[int] = None
    household_size: typing.Optional[int] = None
    email: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Minerals(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    SODIUM = "sodium"
    POTASSIUM = "potassium"
    CALCIUM = "calcium"
    PHOSPHORUS = "phosphorus"
    MAGNESIUM = "magnesium"
    IRON = "iron"
    ZINC = "zinc"
    FLUORIDE = "fluoride"
    CHLORIDE = "chloride"
    _UNKNOWN = "__MINERALS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "Minerals":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        sodium: typing.Callable[[], T_Result],
        potassium: typing.Callable[[], T_Result],
        calcium: typing.Callable[[], T_Result],
        phosphorus: typing.Callable[[], T_Result],
        magnesium: typing.Callable[[], T_Result],
        iron: typing.Callable[[], T_Result],
        zinc: typing.Callable[[], T_Result],
        fluoride: typing.Callable[[], T_Result],
        chloride: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is Minerals.SODIUM:
            return sodium()
        if self is Minerals.POTASSIUM:
            return potassium()
        if self is Minerals.CALCIUM:
            return calcium()
        if self is Minerals.PHOSPHORUS:
            return phosphorus()
        if self is Minerals.MAGNESIUM:
            return magnesium()
        if self is Minerals.IRON:
            return iron()
        if self is Minerals.ZINC:
            return zinc()
        if self is Minerals.FLUORIDE:
            return fluoride()
        if self is Minerals.CHLORIDE:
            return chloride()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OAuthProviders(str, enum.Enum):
    """
    ℹ️ This enum is non-exhaustive.
    """

    OURA = "oura"
    FITBIT = "fitbit"
    GARMIN = "garmin"
    STRAVA = "strava"
    WAHOO = "wahoo"
    IHEALTH = "ihealth"
    WITHINGS = "withings"
    GOOGLE_FIT = "google_fit"
    DEXCOM_V_3 = "dexcom_v3"
    POLAR = "polar"
    CRONOMETER = "cronometer"
    OMRON = "omron"
    WHOOP_V_2 = "whoop_v2"
    MY_FITNESS_PAL_V_2 = "my_fitness_pal_v2"
    ULTRAHUMAN = "ultrahuman"
    _UNKNOWN = "__OAUTHPROVIDERS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "OAuthProviders":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        oura: typing.Callable[[], T_Result],
        fitbit: typing.Callable[[], T_Result],
        garmin: typing.Callable[[], T_Result],
        strava: typing.Callable[[], T_Result],
        wahoo: typing.Callable[[], T_Result],
        ihealth: typing.Callable[[], T_Result],
        withings: typing.Callable[[], T_Result],
        google_fit: typing.Callable[[], T_Result],
        dexcom_v_3: typing.Callable[[], T_Result],
        polar: typing.Callable[[], T_Result],
        cronometer: typing.Callable[[], T_Result],
        omron: typing.Callable[[], T_Result],
        whoop_v_2: typing.Callable[[], T_Result],
        my_fitness_pal_v_2: typing.Callable[[], T_Result],
        ultrahuman: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is OAuthProviders.OURA:
            return oura()
        if self is OAuthProviders.FITBIT:
            return fitbit()
        if self is OAuthProviders.GARMIN:
            return garmin()
        if self is OAuthProviders.STRAVA:
            return strava()
        if self is OAuthProviders.WAHOO:
            return wahoo()
        if self is OAuthProviders.IHEALTH:
            return ihealth()
        if self is OAuthProviders.WITHINGS:
            return withings()
        if self is OAuthProviders.GOOGLE_FIT:
            return google_fit()
        if self is OAuthProviders.DEXCOM_V_3:
            return dexcom_v_3()
        if self is OAuthProviders.POLAR:
            return polar()
        if self is OAuthProviders.CRONOMETER:
            return cronometer()
        if self is OAuthProviders.OMRON:
            return omron()
        if self is OAuthProviders.WHOOP_V_2:
            return whoop_v_2()
        if self is OAuthProviders.MY_FITNESS_PAL_V_2:
            return my_fitness_pal_v_2()
        if self is OAuthProviders.ULTRAHUMAN:
            return ultrahuman()
        return _unknown_member(self._value_)
